@@ -8,8 +8,10 @@ use version;
 use Path::Tiny;
 use Fcntl qw/:seek/;
 use Encode;
-use String::Copyright;
-use String::Copyright 0.002 {
+use String::Copyright 0.003 {
+	format => sub { join ' ', $_->[0] || (), $_->[1] || () }
+};
+use String::Copyright 0.003 {
 	threshold_after => 5,
 	format          => sub { join ' ', $_->[0] || (), $_->[1] || () },
 	},
@@ -26,11 +28,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.20
+Version v3.0.21
 
 =cut
 
-our $VERSION = version->declare("v3.0.20");
+our $VERSION = version->declare("v3.0.21");
 
 =head1 SYNOPSIS
 
